Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cmdline ¶
type Cmdline interface {
Init(chan<- event.Event, <-chan event.Event, chan<- struct{})
Run()
Get() ([]rune, int, []string, int)
}
Cmdline defines the required cmdline interface for the editor.
type Editor ¶
type Editor struct {
// contains filtered or unexported fields
}
Editor is the main struct for this command.
type Manager ¶
type Manager interface {
Init(chan<- event.Event, chan<- struct{})
Open(string) error
Read(io.Reader) error
SetSize(int, int)
Resize(int, int)
Emit(event.Event)
State() (map[int]*state.WindowState, layout.Layout, int, error)
Close()
}
Manager defines the required window manager interface for the editor.
Click to show internal directories.
Click to hide internal directories.